@@ -17,7 +17,7 @@
 
 """Test removing pinned versions in direct dependencies."""
 
-import flexmock
+from flexmock import flexmock
 
 from thoth.adviser.enums import RecommendationType
 from thoth.adviser.pipeline_builder import PipelineBuilderContext
