@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2020 Fridolin Pokorny
+# Copyright(C) 2020 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 """A boot to check Python version configuration used in adviser."""
 
 import logging
-from typing import Optional
+from typing import Generator
 from typing import Dict
 from typing import Any
 from typing import TYPE_CHECKING
@@ -43,14 +43,13 @@ class PythonVersionBoot(Boot):
     _LINK_PY_VER_THOTH_CONF = jl("py_version")
 
     @classmethod
-    def should_include(cls, builder_context: "PipelineBuilderContext") -> Optional[Dict[str, Any]]:
+    def should_include(cls, builder_context: "PipelineBuilderContext") -> Generator[Dict[str, Any], None, None]:
         """Register self, always for adviser."""
-        if not builder_context.is_adviser_pipeline():
+        if builder_context.is_adviser_pipeline() and not builder_context.is_included(cls):
+            yield {}
             return None
 
-        if not builder_context.is_included(cls):
-            return {}
-
+        yield from ()
         return None
 
     def run(self) -> None:
